@@ -1,9 +1,12 @@
 # config.py
 import os
 import traceback
+import re
 from typing import List, Optional
+from pydantic import FilePath
 from pydantic.dataclasses import dataclass
 from dataclasses import asdict
+from pathlib import Path
 import yaml
 
 from akerbp.mlops.core import helpers 
@@ -35,7 +38,7 @@ class EnvVar():
 
 
 # Read environmental variables
-def read_env_vars():
+def _read_env_vars():
     """
     Read environmental variables and initialize EnvVar object with those that
     were set (i.e. ignored those with None value)
@@ -50,9 +53,9 @@ def read_env_vars():
     envs = {k:v for k,v in envs.items() if v}
     return EnvVar(**envs)
 
-envs = read_env_vars()
-envs_dir=asdict(envs)
-logging.debug(f"{envs_dir=}")
+envs = _read_env_vars()
+envs_dic=asdict(envs)
+logging.debug(f"{envs_dic=}")
 
 @dataclass
 class CdfKeys():
@@ -103,11 +106,9 @@ info:
 
 
 def validate_model_reqs(req_file):
-    if not os.path.isfile(req_file):
-        raise ValueError(f"File {req_file} does not exist")
     # Model reqs is renamed to requirements.txt during deployment
-    elif 'requirements.model' in req_file:
-        with open(req_file, 'r') as f: 
+    if req_file.name == 'requirements.model':
+        with req_file.open() as f: 
             req_file_string = f.read()
             if 'akerbp.mlops' not in req_file_string:
                 m = 'Model requirements should include akerbp.mlops package'
@@ -120,18 +121,20 @@ def validate_model_reqs(req_file):
 @dataclass
 class ServiceSettings():
     model_name: str # Remember to modify generate_default_project_settings()
-    model_file: str # if fields are modified
-    req_file: str
-    test_file: str
-    artifact_folder: str
+    model_file: FilePath # if fields are modified
+    req_file: FilePath
+    test_file: Optional[FilePath]
+    artifact_folder: Path
     info: dict
     platform: str = 'cdf'
     model_id: Optional[str] = None
 
-    def __post_init__(self):
+
+    def __post_init_post_parse__(self):
         # Validation
-        if not os.path.isfile(self.model_file):
-            raise ValueError(f"File {self.model_file} does not exist")
+        if not re.match("^[A-Za-z0-9_-]*$", self.model_name):
+            raise Exception("Model name can only contain letters, numbers"
+                            "underscores and dashes")
 
         validate_model_reqs(self.req_file)
 
@@ -143,11 +146,11 @@ class ServiceSettings():
 
         if self.model_id and envs.service_name == 'training':
             raise ValueError("Unexpected model_id setting (training service)")
-
-    def __post_init_post_parse__(self):
+        
         # Derived fields
         if envs.env == 'dev' and not envs.local_deployment:
             self.platform = 'local'
+        
         self.model_import_path = helpers.as_import_path(self.model_file)
         self.test_import_path = helpers.as_import_path(self.test_file)
 
@@ -165,10 +168,20 @@ class ServiceSettings():
             self.files = {**self.files, **files_gc}
 
 
-def store_service_settings(c, yaml_file='mlops_service_settings.yaml'):
+def store_service_settings(c, yaml_file=Path('mlops_service_settings.yaml')):
     logging.info("Write service settings file")
-    service_settings=asdict(c)
-    with open(yaml_file, 'w') as f:
+
+    def factory(data):
+        """
+        Take a list of tuples as input. Returns a suitable dictionary.
+        Transforms Path objects to strings (linux style path).
+        """
+        path2str = lambda x: x if not isinstance(x,Path) else x.as_posix()
+        d = {k:path2str(v) for k,v in data}
+        return d
+    
+    service_settings=asdict(c, dict_factory=factory)
+    with yaml_file.open('w') as f:
         yaml.dump(service_settings,f)
 
 
@@ -177,9 +190,9 @@ class ProjectSettings():
     project_settings: List[ServiceSettings]
 
 
-def read_project_settings(yaml_file='mlops_settings.yaml'):
+def read_project_settings(yaml_file=Path('mlops_settings.yaml')):
     logging.info(f"Read project settings")
-    with open(yaml_file, 'r') as f:
+    with yaml_file.open() as f:
         settings = yaml.safe_load_all(f.read())
     model_settings = [ServiceSettings(**s) for s in settings]
     project_settings = ProjectSettings(project_settings=model_settings)
@@ -187,16 +200,16 @@ def read_project_settings(yaml_file='mlops_settings.yaml'):
     return project_settings.project_settings
 
 
-def read_service_settings(yaml_file='mlops_service_settings.yaml'):
+def read_service_settings(yaml_file=Path('mlops_service_settings.yaml')):
     logging.info(f"Read service settings")
-    with open(yaml_file, 'r') as f:
+    with yaml_file.open() as f:
         settings = yaml.safe_load(f.read())
     service_settings = ServiceSettings(**settings)
     logging.debug(f"{service_settings=}")
     return service_settings
 
 
-def validate_user_settings(yaml_file='mlops_settings.yaml'):
+def validate_user_settings(yaml_file=Path('mlops_settings.yaml')):
     try:
         read_project_settings(yaml_file)
         logging.info("Settings file is ok :)")
@@ -204,6 +217,3 @@ def validate_user_settings(yaml_file='mlops_settings.yaml'):
         trace = traceback.format_exc()
         error_message = f"Settings file is not ok! Fix this:\n{trace}"
         logging.error(error_message)
-
-
-
