@@ -15,6 +15,8 @@ google_project_id = config.envs.google_project_id
 service_name = config.envs.service_name
 logging=logger.get_logger(name='mlops_gc')
 
+env_vars = {k.upper():str(v) for k,v in config.envs_dic.items() if v}
+env_vars.update({'PLATFORM':'gc'})
 
 
 def create_service_account(service_account):
@@ -63,7 +65,7 @@ def create_image(image_name, folder='.'):
     subprocess.check_call(
         (f"gcloud builds submit {folder} "
          f"--tag gcr.io/{google_project_id}/{image_name} "
-          "--quiet"
+          "--no-user-output-enabled"
         ), shell=True)
 
 
@@ -78,7 +80,7 @@ def allow_access_to_secrets(service_account, secret_names=["mlops-cdf-keys"]):
             (f"gcloud secrets add-iam-policy-binding {secret_name} "
              f"--member serviceAccount:{s_a_id} "
               "--role roles/secretmanager.secretAccessor "
-              "--quiet"
+              "--no-user-output-enabled"
             ), shell=True)
 
 
@@ -86,11 +88,11 @@ def run_container(image_name, service_account):
     """
     Run container with a service account
     """
-    logging.info(f"Run container, {image_name=}, {service_account=}")
-    env_vars = {k.upper():v for k,v in config.envs_dir.items() if v}
-    env_vars.update(dict(DEPLOYMENT_PLATFORM='cdf'))    
-    env_vars = [f"{k}={v}" for k,v in env_vars.items() if v]
-    env_vars=','.join(env_vars)
+    logging.info(
+        f"Run container, {image_name=}, {service_account=}, {env_vars=}"
+    )
+    _env_vars = [f"{k}={v}" for k,v in env_vars.items()]
+    _env_vars=','.join(_env_vars)
     
     subprocess.check_call(
         (f"gcloud run deploy {image_name} "
@@ -101,8 +103,7 @@ def run_container(image_name, service_account):
           "--no-user-output-enabled "
           "--memory=512M "
          f"--service-account {service_account} "
-         f"--set-env-vars={env_vars} "
-          "--quiet"
+         f"--set-env-vars={_env_vars} "
         ), shell=True)
 
 
